import * as React from "react";
import type { HyperlinkProps } from "@igloo-ui/hyperlink";
import "./alert.scss";
export type Type = "announcement" | "info" | "premium" | "success" | "warning";
export type Appearance = "card" | "inline" | "horizontal";
export interface AlertButton {
    label: string;
    onClick: () => void;
}
export interface AlertProps extends Omit<React.ComponentProps<"div">, "title"> {
    /** The title of the alert */
    title?: React.ReactNode;
    /** The content to display inside the Alert */
    message?: React.ReactNode;
    /** Additional text to display at the top right of the Alert */
    metadata?: React.ReactNode;
    /** Change the type of the Alert */
    type: Type;
    /** Change the Alert appearance */
    appearance?: Appearance;
    /** Add a specific class to the Alert */
    className?: string;
    /** Set if the Alert can be closed by the user */
    closable?: boolean;
    /** Custom icon for alert (Use 'null' to have no icon) */
    icon?: React.ReactElement | null;
    /** Action on Alert close button click */
    onClose?: () => void;
    /** Alert button */
    button?: AlertButton;
    /** Add a data-test tag for automated tests */
    dataTest?: string;
    /** Alert Link. Used in place of the button */
    link?: HyperlinkProps;
}
declare const Alert: React.FunctionComponent<AlertProps>;
export default Alert;
